@@ -9,13 +9,14 @@ our @ISA = qw{ Module::Build };
 use Carp;
 # use lib 'inc';	# Already done because this module is running.
 use My::Module::Recommend;
-use My::Module::Test ();
 
 
 sub ACTION_authortest {
 ##  my ( $self, @args ) = @_;
     my ( $self ) = @_;		# Arguments not used
 
+    require My::Module::Test;
+
     local $ENV{AUTHOR_TESTING} = 1;
     local $ENV{SPACETRACK_IDENTITY} = undef;
     local $ENV{SPACETRACK_OPT} = undef;
@@ -103,7 +104,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2011-2018 by Thomas R. Wyant, III
+Copyright (C) 2009, 2011-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
